@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/Attribute.pm
-## Version v0.2.0
-## Copyright(c) 2021 DEGUEST Pte. Ltd.
+## Version v0.3.0
+## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/04/22
-## Modified 2022/09/18
+## Modified 2025/10/16
 ## All rights reserved
 ## 
 ## 
@@ -20,8 +20,8 @@ BEGIN
     use vars qw( $VERSION );
     use HTML::Object::Literal;
     use HTML::Object::Number;
-    use Want;
-    our $VERSION = 'v0.2.0';
+    use Wanted;
+    our $VERSION = 'v0.3.0';
 };
 
 use strict;
@@ -88,7 +88,7 @@ HTML::Object::Attribute - HTML Object Element Attribute Class
 
 =head1 VERSION
 
-    v0.2.0
+    v0.3.0
 
 =head1 DESCRIPTION
 
