@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/DOM/Element/Image.pm
-## Version v0.1.0
+## Version v0.2.0
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/12/23
-## Modified 2021/12/23
+## Modified 2022/09/18
 ## All rights reserved
 ## 
 ## 
@@ -17,10 +17,14 @@ BEGIN
     use strict;
     use warnings;
     use parent qw( HTML::Object::DOM::Element );
+    use vars qw( $VERSION );
     use HTML::Object::DOM::Element::Shared qw( :img );
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.2.0';
 };
 
+use strict;
+use warnings;
+
 sub init
 {
     my $self = shift( @_ );
@@ -83,7 +87,7 @@ sub x : lvalue { return( shift->_set_get_number( 'x', @_ ) ); }
 sub y : lvalue { return( shift->_set_get_number( 'y', @_ ) ); } # ::
 
 1;
-# XXX POD
+# NOTE: POD
 __END__
 
 =encoding utf-8
@@ -100,7 +104,7 @@ HTML::Object::DOM::Element::Image - HTML Object DOM Image Class
 
 =head1 VERSION
 
-    v0.1.0
+    v0.2.0
 
 =head1 DESCRIPTION
 
