@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/DOM/Element/Input.pm
-## Version v0.2.1
-## Copyright(c) 2022 DEGUEST Pte. Ltd.
+## Version v0.2.2
+## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/12/23
-## Modified 2023/11/05
+## Modified 2023/11/06
 ## All rights reserved
 ## 
 ## 
@@ -19,9 +19,8 @@ BEGIN
     use parent qw( HTML::Object::DOM::Element );
     use vars qw( $VERSION );
     use HTML::Object::DOM::Element::Shared qw( :input );
-    use Nice::Try;
     use POSIX ();
-    our $VERSION = 'v0.2.1';
+    our $VERSION = 'v0.2.2';
 };
 
 use strict;
@@ -293,7 +292,8 @@ sub _set_up_down
         }
     }
     
-    try
+    # try-catch
+    my $rv = eval
     {
         my $new;
         if( $type eq 'number' || $type eq 'range' )
@@ -463,14 +463,15 @@ sub _set_up_down
         # $self->value = $new;
         $self->value( $new );
         return( $self );
-    }
-    catch( $e )
+    };
+    if( $@ )
     {
         return( $self->error({
-            message => "Error " . ( $opts->{direction} ? 'increasing' : 'decreasing' ) . " the input value: $e",
+            message => "Error " . ( $opts->{direction} ? 'increasing' : 'decreasing' ) . " the input value: $@",
             class => 'HTML::Object::InvalidStateError',
         }) );
     }
+    return( $rv );
 }
 
 1;
@@ -491,7 +492,7 @@ HTML::Object::DOM::Element::Input - HTML Object DOM Input Class
 
 =head1 VERSION
 
-    v0.2.1
+    v0.2.2
 
 =head1 DESCRIPTION
 
