@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/DOM/Element/Title.pm
-## Version v0.2.1
+## Version v0.3.0
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/01/09
-## Modified 2022/09/20
+## Modified 2025/10/16
 ## All rights reserved
 ## 
 ## 
@@ -18,8 +18,8 @@ BEGIN
     use warnings;
     use parent qw( HTML::Object::DOM::Element );
     use vars qw( $VERSION );
-    use Want;
-    our $VERSION = 'v0.2.1';
+    use Wanted;
+    our $VERSION = 'v0.3.0';
 };
 
 use strict;
@@ -135,7 +135,7 @@ HTML::Object::DOM::Element::Title - HTML Object DOM Title Class
 
 =head1 VERSION
 
-    v0.2.1
+    v0.3.0
 
 =head1 DESCRIPTION
 
